summaryrefslogtreecommitdiffstats
path: root/src/plugins/canbus/systeccan/systeccanbackend.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugins/canbus/systeccan/systeccanbackend.cpp')
-rw-r--r--src/plugins/canbus/systeccan/systeccanbackend.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/plugins/canbus/systeccan/systeccanbackend.cpp b/src/plugins/canbus/systeccan/systeccanbackend.cpp
index f33d9ba..3fdd135 100644
--- a/src/plugins/canbus/systeccan/systeccanbackend.cpp
+++ b/src/plugins/canbus/systeccan/systeccanbackend.cpp
@@ -479,11 +479,11 @@ bool SystecCanBackend::open()
if (!d->open())
return false;
// Apply all stored configurations except bitrate, because
// the bitrate can not be applied after opening the device
const QVector<int> keys = configurationKeys();
for (int key : keys) {
- if (key == QCanBusDevice::BitRateKey)
+ if (key == BitRateKey || key == ReceiveOwnKey)
continue;
const QVariant param = configurationParameter(key);
const bool success = d->setConfigurationParameter(key, param);
@@ -479,11 +479,11 @@ bool SystecCanBackend::open()
if (!d->open())
return false;
- // Apply all stored configurations except bitrate, because
- // the bitrate can not be applied after opening the device
+ // Apply all stored configurations except bitrate and receive own,
+ // because these cannot be applied after opening the device
const QVector<int> keys = configurationKeys();
for (int key : keys) {